KernelChecks

Struct KernelChecks 

pub struct KernelChecks { /* private fields */ }

Implementations

Source

impl KernelChecks

pub fn new(host_executor: HostNamespaceExecutor) -> Self

pub async fn run_all(&self) -> CheckGroupResult

Run all the checkers asynchronously, then join and collect the results.

pub async fn has_modules(&self) -> CheckResult

Checks that nf_tables and msr are either built into or loaded by the running kernel.

Manual equivalent:

grep -E 'nf_tables|msr' /lib/modules/$(uname -r)/modules.builtin
grep -E '^nf_tables |^msr ' /proc/modules