pub struct PostinstallKernelChecks { /* private fields */ }Implementations
Sourceimpl PostinstallKernelChecks
impl PostinstallKernelChecks
pub fn new(host_executor: HostNamespaceExecutor) -> Self
Sourcepub async fn run_all(&self) -> CheckGroupResult
pub async fn run_all(&self) -> CheckGroupResult
Run all the checkers asynchronously, then join and collect the results.
Sourcepub async fn version_is_good(&self) -> CheckResult
pub async fn version_is_good(&self) -> CheckResult
Checks that the running kernel is at least version 5.15.0.
Manual equivalent:
uname -r # must be >= 5.15.0Sourcepub async fn has_modules(&self) -> CheckResult
pub async fn has_modules(&self) -> CheckResult
Checks that all required Xen and networking modules are available as built-in,
currently loaded, or loadable (present in modules.dep) for the running kernel.
Manual equivalent:
KV=$(uname -r)
for mod in nf_tables xen_evtchn xen-privcmd xen-netback xen-pciback xen-blkback xen-gntdev xen-gntalloc; do
grep -q "$mod" /lib/modules/$KV/modules.builtin \
|| grep -q "^${mod} " /proc/modules \
|| grep -q "$mod" /lib/modules/$KV/modules.dep \
&& echo "$mod: OK" || echo "$mod: MISSING"
doneAuto Trait Implementations
impl Freeze for PostinstallKernelChecks
impl RefUnwindSafe for PostinstallKernelChecks
impl Send for PostinstallKernelChecks
impl Sync for PostinstallKernelChecks
impl Unpin for PostinstallKernelChecks
impl UnsafeUnpin for PostinstallKernelChecks
impl UnwindSafe for PostinstallKernelChecks