pub struct KernelChecks { /* private fields */ }Implementations
Sourceimpl KernelChecks
impl KernelChecks
pub fn new(host_executor: HostNamespaceExecutor) -> Self
Sourcepub async fn run_all(&self) -> CheckGroupResult
pub async fn run_all(&self) -> CheckGroupResult
Run all the checkers asynchronously, then join and collect the results.
Sourcepub async fn has_modules(&self) -> CheckResult
pub async fn has_modules(&self) -> CheckResult
Checks that nf_tables and msr are either built into or loaded by the running kernel.
Manual equivalent:
grep -E 'nf_tables|msr' /lib/modules/$(uname -r)/modules.builtin
grep -E '^nf_tables |^msr ' /proc/modulesAuto Trait Implementations
impl Freeze for KernelChecks
impl RefUnwindSafe for KernelChecks
impl Send for KernelChecks
impl Sync for KernelChecks
impl Unpin for KernelChecks
impl UnsafeUnpin for KernelChecks
impl UnwindSafe for KernelChecks