pub struct SystemRecorder { /* private fields */ }Implementations
Sourceimpl SystemRecorder
impl SystemRecorder
pub fn new(host_executor: HostNamespaceExecutor) -> Self
Sourcepub async fn run_all(&self) -> CheckGroupResult
pub async fn run_all(&self) -> CheckGroupResult
Run all the recorders asynchronously, then join and collect the results.
Sourcepub async fn record_lspci(&self) -> CheckResult
pub async fn record_lspci(&self) -> CheckResult
Records verbose PCI device listing.
Manual equivalent:
lspci -vvvSourcepub async fn record_dmidecode(&self) -> CheckResult
pub async fn record_dmidecode(&self) -> CheckResult
Records DMI/SMBIOS hardware information (BIOS, board, chassis, CPU, memory).
Manual equivalent:
dmidecodeSourcepub async fn record_hv_console(&self) -> CheckResult
pub async fn record_hv_console(&self) -> CheckResult
Records the Xen hypervisor console log via the protect-ctl tool.
Manual equivalent:
protect-ctl host hv-consoleSourcepub async fn record_hv_debug_info(&self) -> CheckResult
pub async fn record_hv_debug_info(&self) -> CheckResult
Records the Xen hypervisor debug state via the protect-ctl tool.
Manual equivalent:
protect-ctl host hv-debug-infoSourcepub async fn record_daemon_logs(&self) -> CheckResult
pub async fn record_daemon_logs(&self) -> CheckResult
Records the protect-daemon journalctl log.
Manual equivalent:
journalctl -u protect-daemonSourcepub async fn record_cri_logs(&self) -> CheckResult
pub async fn record_cri_logs(&self) -> CheckResult
Records the protect-cri journalctl log.
Manual equivalent:
journalctl -u protect-criSourcepub async fn record_storage_logs(&self) -> CheckResult
pub async fn record_storage_logs(&self) -> CheckResult
Records the protect-storage journalctl log.
Manual equivalent:
journalctl -u protect-storageSourcepub async fn record_network_logs(&self) -> CheckResult
pub async fn record_network_logs(&self) -> CheckResult
Records the protect-network journalctl log.
Manual equivalent:
journalctl -u protect-storageSourcepub async fn record_containerd_logs(&self) -> CheckResult
pub async fn record_containerd_logs(&self) -> CheckResult
Records the containerd journalctl log.
Manual equivalent:
journalctl -u containerdSourcepub async fn record_kubelet_logs(&self) -> CheckResult
pub async fn record_kubelet_logs(&self) -> CheckResult
Records the kubelet journalctl log.
Manual equivalent:
journalctl -u kubeletSourcepub async fn record_cpuinfo(&self) -> CheckResult
pub async fn record_cpuinfo(&self) -> CheckResult
Records CPU hardware details and feature flags.
Manual equivalent:
cat /proc/cpuinfoSourcepub async fn record_cmdline(&self) -> CheckResult
pub async fn record_cmdline(&self) -> CheckResult
Records the kernel command line used to boot the running kernel.
Manual equivalent:
cat /proc/cmdlineSourcepub async fn record_xen_capabilities(&self) -> CheckResult
pub async fn record_xen_capabilities(&self) -> CheckResult
Records the Xen hypervisor capability string.
Manual equivalent:
cat /sys/hypervisor/properties/capabilitiesSourcepub async fn record_grub_cfg(&self) -> CheckResult
pub async fn record_grub_cfg(&self) -> CheckResult
Records the GRUB bootloader configuration. Checks /boot/grub2/grub.cfg first,
falling back to /boot/grub/grub.cfg.
Manual equivalent:
cat /boot/grub2/grub.cfg || cat /boot/grub/grub.cfgSourcepub async fn record_kernel_cfg(&self) -> CheckResult
pub async fn record_kernel_cfg(&self) -> CheckResult
Records the kernel build configuration. Checks /proc/config.gz first (decompressing
if needed), falling back to /boot/config-$(uname -r).
Manual equivalent:
zcat /proc/config.gz || cat /boot/config-$(uname -r)Sourcepub async fn record_loaded_modules(&self) -> CheckResult
pub async fn record_loaded_modules(&self) -> CheckResult
Records the list of currently loaded kernel modules.
Manual equivalent:
cut -d' ' -f1 /proc/modules